@@ -174,7 +174,7 @@ class HTTP:
             else: li = 0
 
             channel = Channel(chatId, li, self.__writer)
-            self.loop.create_task(self.client.on_join(packet, channel))
+            self.loop.create_task(self.client.on_join(channel))
 
         if packet.PacketName == "DELMEM":
             chatId = body["chatLog"]["chatId"]
@@ -183,7 +183,7 @@ class HTTP:
 
             channel = Channel(chatId, li, self.__writer)
             # channel = packet.toJsonBody()
-            self.loop.create_task(self.client.on_quit(packet, channel))
+            self.loop.create_task(self.client.on_quit( channel))
 
         if packet.PacketName == "DECUNREAD":
             chatId = body["chatId"]
